DELETE: messages.json
---------------------

Delete messages from SFChat. It’s used generally as a result of successfully delivery  messages. In this case 
SFChat server keeps only undelivered messages.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Request
   Response
